//
//  This file is an example for SXML, a tool to automate the publication of
//  XML data through the Siena wide-area event notification system.
//
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Copyright (C) 2000-2001 University of Colorado
//
//  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
//  See the file AUTHORS for full details. 
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
// $Id: Publisher.java,v 1.1 2001/01/24 17:16:31 carzanig Exp $
//
package siena.sxml;

import siena.*;
import siena.sxml.*;

/** a utility class to publish XML events from files
 *
 *  <code>Publisher</code> publishes a set of XML documents to a given
 *  Siena server, using a given SXML map.  The document files, the
 *  Siena address and the SXML map are passed as command-line
 *  parameters.  The usage synopsis is as follows:
 *
 *  <p><code>Publisher</code> [<code>--with-xmltext</code>]
 *  <em>siena-server</em> <em>map</em> [<em>xml-document</em> ...]
 *
 *  <p><code>--with-xmltext</code> causes Publisher to attach the XML
 *  source to each notification it publishes.
 *
 *  <p><em>siena-server</em> is the URL of the Siena server
 *
 *  <p><em>map</em> is the name of the file containing the SXML
 *  mapping rules
 *
 *  <p><em>XML-document</em> is a file containing an XML event.  With
 *  no <em>XML-document</em>s <code>Publisher</code> reads one XML
 *  event from the standard input.
 **/
public class Publisher {
    private static void exit_with_usage() {
	System.err.println("Usage: Publisher [--with-xmltext] <siena-server> <map> [xml-document ...]");
	System.exit(1);	
    }

    public static void main(String args[]) {
	try {
	    EventMap m = new EventMap();
	    int i = 0;
	    if (i == args.length) exit_with_usage();

	    if (args[i].equals("--with-xmltext")) {
		m.attachXml();
		++i;
	    }
	    if (i == args.length) exit_with_usage();
	    Siena siena = new ThinClient(args[i++]);
	    if (i == args.length) exit_with_usage();
	    m.importRules(args[i++]);

	    if (i == args.length) {
		siena.publish(m.makeNotification(System.in));
	    } else {
		while(i < args.length)
		    siena.publish(m.makeNotification(args[i++]));
	    }
	} catch (Exception ex) {
	    ex.printStackTrace();
	    System.exit(1);
	}
	System.exit(0);
    }
};
