//
//  This file is part of SXML, a tool to automate the publication of
//  XML data through the Siena wide-area event notification system.
//
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Copyright (C) 2000-2001 University of Colorado
//
//  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
//  See the file AUTHORS for full details. 
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
// $Id: TestXMLNotifiable.java,v 1.2 2001/01/24 17:33:33 carzanig Exp $
//
package sxmltest;

import siena.*;
import siena.sxml.*;

class Subscriber implements XMLNotifiable {
    public void notifyXml(String xml_event) {
	System.out.println("XML Event:\n" + xml_event);
    }

    /** notifies a sequence of XML events
     **/
    public void notifyXml(String[] xml_events) {};
}

public class TestXMLNotifiable {
    public static void main(String args[]) {

	if (args.length != 1) {
	    System.err.println("Usage: TestXMLNotifiable <siena-server>");
	    System.exit(1);
	}
	try {
	    ThinClient siena = new ThinClient(args[0]);

	    Filter f = new Filter();
	    f.addConstraint("name",Op.ANY,"");

	    XMLNotifiableWrapper wrapper;
	    wrapper = new XMLNotifiableWrapper(new Subscriber());
	    
	    siena.subscribe(f, wrapper);
	    Thread.sleep(10000);
	    siena.unsubscribe(wrapper);
	    siena.shutdown();
	} catch (Exception ex) {
	    ex.printStackTrace();
	    System.exit(1);
	}
	System.exit(0);
    }
}
