#
#  This file is part of SXML.  SXML automates the conversion of XML
#  data into Siena event notifications.  For more information, see:
#  http://www.cs.colorado.edu/serl/siena/
#
#  Copyright (C) 2000-2001 University of Colorado
#
#  Author: Antonio Carzaniga <carzanig@cs.colorado.edu>
#  See the file AUTHORS for full details. 
#  
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License (file LICENSE) for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with this program (see LICENSE); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
#  USA, or send email to serl@cs.colorado.edu.
#
# $Id: test_endtoend.sh,v 1.3 2001/01/24 17:33:43 carzanig Exp $
#
. ./config.sh
#
echo Testing end-to-end siena.sxml communication...
cat > test.map <<EOF
string	name="/person/@name" first;
string	items="/person/item/@id" separator ",";
int	age="/person/@age";
float	job/salary="/person/@salary" first ;
string	father="/person/parent[1]/@name";
string	mother="/person/parent[2]/@name";
string  parents="/person/parent/@name" separator "+";
string  XML="/person/item" separator "###";
EOF
cat > test.xml <<EOF
<person name="Antonio" age="31">
<item id="ciao">bla</item>
<item id="miao"/>
<parent name="Alberto" age="64">papa</parent>
<parent name="Aida" age="64">mamma</parent>
</person>
EOF
port=2323
$JAVA siena.StartServer -port $port &
server=$!
sleep 1
$JAVA sxmltest.TestXMLNotifiable senp://localhost:$port > test.out &
client=$!
$JAVA siena.sxml.Publisher --with-xmltext senp://localhost:$port test.map test.xml
$JAVA siena.sxml.Publisher --with-xmltext senp://localhost:$port test.map < test.xml
wait $client
kill $server & 
wait $server
cat > test.expected <<EOF
XML Event:
<?xml version="1.0"?>
<person age="31" name="Antonio"> <item id="ciao">bla</item> <item id="miao"/> <parent age="64" name="Alberto">papa</parent> <parent age="64" name="Aida">mamma</parent> </person>
XML Event:
<?xml version="1.0"?>
<person age="31" name="Antonio"> <item id="ciao">bla</item> <item id="miao"/> <parent age="64" name="Alberto">papa</parent> <parent age="64" name="Aida">mamma</parent> </person>
EOF
if diff test.out test.expected; then
    echo "PASSED."
    exit 0
else
    echo "FAILED."
    exit 1
fi
